@@ -31,12 +31,7 @@
 #include <tdeversion.h>
 
 // include files for KDE
-#if TDE_VERSION > 300
 #include <tdeapplication.h>
-#else
-#include <kapp.h>
-#endif // KDE 3.x
-
 #include <kkeydialog.h>
 #include <kinputdialog.h>
 #include <kiconloader.h>
